summaryrefslogtreecommitdiffstats
path: root/source/WebAdmin.cpp
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--source/WebAdmin.cpp13
1 files changed, 9 insertions, 4 deletions
diff --git a/source/WebAdmin.cpp b/source/WebAdmin.cpp
index 378a5966c..c917ec658 100644
--- a/source/WebAdmin.cpp
+++ b/source/WebAdmin.cpp
@@ -488,15 +488,20 @@ void cWebAdmin::OnRequestFinished(cHTTPConnection & a_Connection, cHTTPRequest &
)
{
HandleWebadminRequest(a_Connection, a_Request);
- return;
}
- if (URL == "/")
+ else if (URL == "/")
{
// The root needs no body handler and is fully handled in the OnRequestFinished() call
HandleRootRequest(a_Connection, a_Request);
- return;
}
- // TODO: Handle other requests
+ else
+ {
+ // TODO: Handle other requests
+ }
+
+ // Delete any request data assigned to the request:
+ cRequestData * Data = (cRequestData *)(a_Request.GetUserData());
+ delete Data;
}